#ifndef BLE_CNTS_H__
#define BLE_CNTS_H__

#include <stdint.h>
#include <stdbool.h>
#include "ble.h"
#include "ble_srv_common.h"

#define CNTS_UUID_BASE {0x23, 0xD1, 0xBC, 0xEA, 0x5F, 0x78, 0x23, 0x15, 0xDE, 0xEF, 0x12, 0x12, 0x00, 0x00, 0x00, 0x00}
#define CNTS_UUID_SERVICE 0x1523
#define CNTS_UUID_COUNT 0x1524


// Forward declaration of the ble_lbs_t type.
typedef struct ble_cnts_s ble_cnts_t;

/**@brief LEDButton Service event handler type. */
typedef void (*ble_cnts_write_handler_t) (ble_cnts_t * p_cnts, uint8_t new_state);

/**@brief LEDButton Service init structure. This contains all options and data needed for
 *        initialization of the service.*/
typedef struct
{
    ble_cnts_write_handler_t   cnts_write_handler;
} ble_cnts_init_t;


/**@brief LEDButton Service structure. This contains various status information for the service. */
typedef struct ble_cnts_s
{
    uint16_t                     service_handle;
    ble_gatts_char_handles_t     cnts_handles;
    ble_gatts_char_handles_t     button_char_handles;
    uint8_t                      uuid_type;
    uint8_t                      current_led_state;
    uint16_t                     conn_handle;
    bool                         is_notifying;
    ble_cnts_write_handler_t  	cnts_write_handler;
} ble_cnts_t;

uint32_t ble_cnts_init(ble_cnts_t * p_lbs, const ble_cnts_init_t * p_lbs_init);
void ble_lbs_on_ble_evt(ble_cnts_t * p_lbs, ble_evt_t * p_ble_evt);
uint32_t ble_cnts_change(ble_cnts_t * p_cnts, uint8_t count);
#endif
